@@ -18,12 +18,12 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'CFLAGS': '-fno-strict-aliasing -g -O2 -DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes',
  'CFLAGSFORSHARED': '-fPIC',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in',
- 'CONFIG_ARGS': "'--enable-shared' '--enable-ipv6' '--enable-unicode=ucs4' '--prefix=/opt/anaconda1anaconda2anaconda3' '--with-tcltk-includes=-I/opt/anaconda1anaconda2anaconda3/include' '--with-tcltk-libs=-L/opt/anaconda1anaconda2anaconda3/lib -ltcl8.5 -ltk8.5' 'CPPFLAGS=-I/opt/anaconda1anaconda2anaconda3/include' 'LDFLAGS=-L/opt/anaconda1anaconda2anaconda3/lib -Wl,-rpath=/opt/anaconda1anaconda2anaconda3/lib,--no-as-needed' 'PKG_CONFIG_PATH=/opt/anaconda1anaconda2anaconda3/lib/pkgconfig'",
+ 'CONFIG_ARGS': "'--enable-shared' '--enable-ipv6' '--enable-unicode=ucs4' '--prefix=/opt/anaconda1anaconda2anaconda3' '--with-tcltk-includes=-I/opt/anaconda1anaconda2anaconda3/include' '--with-tcltk-libs=-L/opt/anaconda1anaconda2anaconda3/lib -ltcl8.6 -ltk8.6' 'CPPFLAGS=-I/opt/anaconda1anaconda2anaconda3/include' 'LDFLAGS=-L/opt/anaconda1anaconda2anaconda3/lib -Wl,-rpath=/opt/anaconda1anaconda2anaconda3/lib,--no-as-needed' 'PKG_CONFIG_PATH=/opt/anaconda1anaconda2anaconda3/lib/pkgconfig'",
  'CONFINCLUDEDIR': '/opt/anaconda1anaconda2anaconda3/include',
  'CONFINCLUDEPY': '/opt/anaconda1anaconda2anaconda3/include/python2.7',
  'COREPYTHONPATH': ':plat-linux2:lib-tk:lib-old',
- 'COVERAGE_INFO': '/feedstock_root/build_artefacts/python_1507213136859/work/Python-2.7.14/coverage.info',
- 'COVERAGE_REPORT': '/feedstock_root/build_artefacts/python_1507213136859/work/Python-2.7.14/lcov-report',
+ 'COVERAGE_INFO': '/home/conda/feedstock_root/build_artifacts/python_1525790729080/work/coverage.info',
+ 'COVERAGE_REPORT': '/home/conda/feedstock_root/build_artifacts/python_1525790729080/work/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov report"',
  'CPPFLAGS': '-I. -IInclude -I./Include -I/opt/anaconda1anaconda2anaconda3/include',
  'CXX': 'g++ -pthread',
@@ -87,12 +87,21 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_CONFSTR': 1,
  'HAVE_CONIO_H': 0,
  'HAVE_COPYSIGN': 1,
+ 'HAVE_CRYPT_H': 1,
  'HAVE_CTERMID': 1,
  'HAVE_CTERMID_R': 0,
+ 'HAVE_CURSES_FILTER': 1,
  'HAVE_CURSES_H': 1,
+ 'HAVE_CURSES_HAS_KEY': 1,
+ 'HAVE_CURSES_IMMEDOK': 1,
+ 'HAVE_CURSES_IS_PAD': 1,
  'HAVE_CURSES_IS_TERM_RESIZED': 1,
  'HAVE_CURSES_RESIZETERM': 1,
  'HAVE_CURSES_RESIZE_TERM': 1,
+ 'HAVE_CURSES_SYNCOK': 1,
+ 'HAVE_CURSES_TYPEAHEAD': 1,
+ 'HAVE_CURSES_USE_ENV': 1,
+ 'HAVE_CURSES_WCHGAT': 1,
  'HAVE_DECL_ISFINITE': 1,
  'HAVE_DECL_ISINF': 1,
  'HAVE_DECL_ISNAN': 1,
@@ -306,6 +315,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_SYS_SOCKET_H': 1,
  'HAVE_SYS_STATVFS_H': 1,
  'HAVE_SYS_STAT_H': 1,
+ 'HAVE_SYS_SYSMACROS_H': 1,
  'HAVE_SYS_TERMIO_H': 0,
  'HAVE_SYS_TIMES_H': 1,
  'HAVE_SYS_TIME_H': 1,
@@ -455,7 +465,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'RANLIB': 'ranlib',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/feedstock_root/build_artefacts/python_1507213136859/work/Python-2.7.14',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/home/conda/feedstock_root/build_artifacts/python_1525790729080/work',
  'SCRIPTDIR': '/opt/anaconda1anaconda2anaconda3/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '',
@@ -494,11 +504,11 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TANH_PRESERVES_ZERO_SIGN': 1,
  'TCLTK_INCLUDES': '-I/opt/anaconda1anaconda2anaconda3/include',
- 'TCLTK_LIBS': '-L/opt/anaconda1anaconda2anaconda3/lib -ltcl8.5 -ltk8.5',
+ 'TCLTK_LIBS': '-L/opt/anaconda1anaconda2anaconda3/lib -ltcl8.6 -ltk8.6',
  'TESTOPTS': '-l',
  'TESTPATH': '',
  'TESTPROG': './Lib/test/regrtest.py',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/feedstock_root/build_artefacts/python_1507213136859/work/Python-2.7.14 ./python -Wd -3 -E -tt',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/home/conda/feedstock_root/build_artifacts/python_1525790729080/work ./python -Wd -3 -E -tt',
  'TESTPYTHONOPTS': '',
  'THREADOBJ': 'Python/thread.o',
  'TIME_WITH_SYS_TIME': 1,
@@ -523,8 +533,8 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/feedstock_root/build_artefacts/python_1507213136859/work/Python-2.7.14',
- 'abs_srcdir': '/feedstock_root/build_artefacts/python_1507213136859/work/Python-2.7.14',
+ 'abs_builddir': '/home/conda/feedstock_root/build_artifacts/python_1525790729080/work',
+ 'abs_srcdir': '/home/conda/feedstock_root/build_artifacts/python_1525790729080/work',
  'build': 'x86_64-pc-linux-gnu',
  'datarootdir': '/opt/anaconda1anaconda2anaconda3/share',
  'exec_prefix': '/opt/anaconda1anaconda2anaconda3',
