@@ -18,8 +18,8 @@ ppc64le = bool(platform.machine() == 'ppc64le')
 debug = int(os.getenv('DEBUG', 0))
 
 print('Python version:', platform.python_version())
-assert platform.python_version() == '2.7.14'
-assert sys.version_info[:3] == (2, 7, 14)
+assert platform.python_version() == '2.7.15'
+assert sys.version_info[:3] == (2, 7, 15)
 if sys.platform == 'win32':
     assert 'MSC v.1500' in sys.version
 print('max unicode:', sys.maxunicode)
@@ -80,6 +80,8 @@ import ssl
 import strop
 import time
 import test
+import test.support
+import test.test_support
 import unicodedata
 import zlib
 import gzip
@@ -121,7 +123,8 @@ if not (armv7l or ppc64le):
     import turtle
     print('TK_VERSION:', _tkinter.TK_VERSION)
     print('TCL_VERSION:', _tkinter.TCL_VERSION)
-    assert _tkinter.TK_VERSION == _tkinter.TCL_VERSION == '8.5'
+    TCLTK_VER = '8.5' if sys.platform == 'win32' else '8.6'
+    assert _tkinter.TK_VERSION == _tkinter.TCL_VERSION == TCLTK_VER
 
 print('OPENSSL_VERSION:', ssl.OPENSSL_VERSION)
 if sys.platform != 'win32':
